==> plus-tree-selection-1.0.3.tgz: package/es/components/advance-tree-selection/index.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
import "antd/es/form/style";
import _Form from "antd/es/form";
var _excluded = ["isMultiple", "showClearButton", "getEmployeeOrdepartmentTree", "getSearchEmployeeByNameAndPhoneAndEmial", "listType", "title", "searchPlaceholder", "modalTitle", "value", "needForm", "env"];
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(arr, i) { var _i = null == arr ? null : "undefined" != typeof Symbol && arr[Symbol.iterator] || arr["@@iterator"]; if (null != _i) { var _s, _e, _x, _r, _arr = [], _n = !0, _d = !1; try { if (_x = (_i = _i.call(arr)).next, 0 === i) { if (Object(_i) !== _i) return; _n = !1; } else for (; !(_n = (_s = _x.call(_i)).done) && (_arr.push(_s.value), _arr.length !== i); _n = !0); } catch (err) { _d = !0, _e = err; } finally { try { if (!_n && null != _i.return && (_r = _i.return(), Object(_r) !== _r)) return; } finally { if (_d) throw _e; } } return _arr; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React from 'react';
import SelectTree from '../base-tree-selection';
import FormInModal from '../form-in-modal';
import { useSelectTree, useGetTreeDateAndRootId } from './hook';
var Item = _Form.Item;
var AdvanceTreeSelection = function AdvanceTreeSelection(props) {
  var _props$isMultiple = props.isMultiple,
    isMultiple = _props$isMultiple === void 0 ? true : _props$isMultiple,
    showClearButton = props.showClearButton,
    getEmployeeOrdepartmentTree = props.getEmployeeOrdepartmentTree,
    getSearchEmployeeByNameAndPhoneAndEmial = props.getSearchEmployeeByNameAndPhoneAndEmial,
    listType = props.listType,
    title = props.title,
    searchPlaceholder = props.searchPlaceholder,
    modalTitle = props.modalTitle,
    value = props.value,
    _props$needForm = props.needForm,
    needForm = _props$needForm === void 0 ? true : _props$needForm,
    env = props.env,
    restProps = _objectWithoutProperties(props, _excluded);
  var _useSelectTree = useSelectTree(_objectSpread(_objectSpread({}, restProps), {}, {
      value: value,
      isMultiple: isMultiple,
      showClearButton: showClearButton,
      getSearchEmployeeByNameAndPhoneAndEmial: getSearchEmployeeByNameAndPhoneAndEmial,
      env: env
    })),
    visible = _useSelectTree.visible,
    onCancelSubmit = _useSelectTree.onCancelSubmit,
    onSubmitSuccess = _useSelectTree.onSubmitSuccess,
    renderMultipleSelectOrSelect = _useSelectTree.renderMultipleSelectOrSelect,
    onChange = _useSelectTree.onChange,
    hasSelectedKeys = _useSelectTree.hasSelectedKeys,
    getSearchResultByname = _useSelectTree.getSearchResultByname;
  var _useGetTreeDateAndRoo = useGetTreeDateAndRootId(getEmployeeOrdepartmentTree, listType, isMultiple, env),
    _useGetTreeDateAndRoo2 = _slicedToArray(_useGetTreeDateAndRoo, 2),
    treeData = _useGetTreeDateAndRoo2[0],
    rootId = _useGetTreeDateAndRoo2[1];
  var renderForm = function renderForm(needForm) {
    var tree = /*#__PURE__*/React.createElement(SelectTree, {
      hasSelectedKeys: hasSelectedKeys,
      rootId: rootId,
      showClearButton: showClearButton,
      data: treeData,
      title: title,
      checkable: isMultiple,
      listType: listType,
      searchPlaceholder: searchPlaceholder,
      getSearchResultByname: getSearchResultByname,
      onSelectResult: onChange,
      env: env
    });
    if (needForm) {
      return /*#__PURE__*/React.createElement(React.Fragment, null, renderMultipleSelectOrSelect(isMultiple), /*#__PURE__*/React.createElement(FormInModal, {
        visible: visible,
        title: modalTitle,
        width: 600,
        onSubmitSuccess: onSubmitSuccess,
        onCancelSubmit: onCancelSubmit
      }, /*#__PURE__*/React.createElement(_Form, null, /*#__PURE__*/React.createElement(Item, null, tree))));
    }
    return tree;
  };
  return /*#__PURE__*/React.createElement(React.Fragment, null, renderForm(needForm));
};
export default AdvanceTreeSelection;

==> plus-tree-selection-1.0.4.tgz: package/es/components/advance-tree-selection/index.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
import "antd/es/form/style";
import _Form from "antd/es/form";
var _excluded = ["isMultiple", "showClearButton", "getEmployeeOrdepartmentTree", "getSearchEmployeeByNameAndPhoneAndEmial", "listType", "title", "searchPlaceholder", "modalTitle", "value", "needForm", "env"];
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(r, l) { var t = null == r ? null : "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (null != t) { var e, n, i, u, a = [], f = !0, o = !1; try { if (i = (t = t.call(r)).next, 0 === l) { if (Object(t) !== t) return; f = !1; } else for (; !(f = (e = i.call(t)).done) && (a.push(e.value), a.length !== l); f = !0); } catch (r) { o = !0, n = r; } finally { try { if (!f && null != t.return && (u = t.return(), Object(u) !== u)) return; } finally { if (o) throw n; } } return a; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React from 'react';
import SelectTree from '../base-tree-selection';
import FormInModal from '../form-in-modal';
import { useSelectTree, useGetTreeDateAndRootId } from './hook';
var Item = _Form.Item;
var AdvanceTreeSelection = function AdvanceTreeSelection(props) {
  var _props$isMultiple = props.isMultiple,
    isMultiple = _props$isMultiple === void 0 ? true : _props$isMultiple,
    showClearButton = props.showClearButton,
    getEmployeeOrdepartmentTree = props.getEmployeeOrdepartmentTree,
    getSearchEmployeeByNameAndPhoneAndEmial = props.getSearchEmployeeByNameAndPhoneAndEmial,
    listType = props.listType,
    title = props.title,
    searchPlaceholder = props.searchPlaceholder,
    modalTitle = props.modalTitle,
    value = props.value,
    _props$needForm = props.needForm,
    needForm = _props$needForm === void 0 ? true : _props$needForm,
    env = props.env,
    restProps = _objectWithoutProperties(props, _excluded);
  var _useSelectTree = useSelectTree(_objectSpread(_objectSpread({}, restProps), {}, {
      value: value,
      isMultiple: isMultiple,
      showClearButton: showClearButton,
      getSearchEmployeeByNameAndPhoneAndEmial: getSearchEmployeeByNameAndPhoneAndEmial,
      env: env
    })),
    visible = _useSelectTree.visible,
    onCancelSubmit = _useSelectTree.onCancelSubmit,
    onSubmitSuccess = _useSelectTree.onSubmitSuccess,
    renderMultipleSelectOrSelect = _useSelectTree.renderMultipleSelectOrSelect,
    onChange = _useSelectTree.onChange,
    hasSelectedKeys = _useSelectTree.hasSelectedKeys,
    getSearchResultByname = _useSelectTree.getSearchResultByname;
  var _useGetTreeDateAndRoo = useGetTreeDateAndRootId(getEmployeeOrdepartmentTree, listType, isMultiple, env),
    _useGetTreeDateAndRoo2 = _slicedToArray(_useGetTreeDateAndRoo, 2),
    treeData = _useGetTreeDateAndRoo2[0],
    rootId = _useGetTreeDateAndRoo2[1];
  var renderForm = function renderForm(needForm) {
    var tree = /*#__PURE__*/React.createElement(SelectTree, {
      hasSelectedKeys: hasSelectedKeys,
      rootId: rootId,
      showClearButton: showClearButton,
      data: treeData,
      title: title,
      checkable: isMultiple,
      listType: listType,
      searchPlaceholder: searchPlaceholder,
      getSearchResultByname: getSearchResultByname,
      onSelectResult: onChange,
      env: env
    });
    if (needForm) {
      return /*#__PURE__*/React.createElement(React.Fragment, null, renderMultipleSelectOrSelect(isMultiple), /*#__PURE__*/React.createElement(FormInModal, {
        visible: visible,
        title: modalTitle,
        width: 600,
        onSubmitSuccess: onSubmitSuccess,
        onCancelSubmit: onCancelSubmit
      }, /*#__PURE__*/React.createElement(_Form, null, /*#__PURE__*/React.createElement(Item, null, tree))));
    }
    return tree;
  };
  return /*#__PURE__*/React.createElement(React.Fragment, null, renderForm(needForm));
};
export default AdvanceTreeSelection;
